@@ -76,9 +76,6 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
     if(check_string(version_name)==False):
         printError("Error. The version name you provided, "+version_name+", does not match our naming convention. Please check our documentation for instructions: https://docs.pyqai.com/pyq/fundamentals/naming-conventions")
         return(False)
-    if(memoryLimit>16.0):
-        printError("Error. We currently do not support models larger than 16 GB in our alpha test. Please try again with a smaller model")
-        return(False)
 #endregion
 
 #region Authentication
@@ -155,10 +152,10 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 #endregion
 
 #region Dockerfile and requirements file handling
-    printInfo("Building requirements.txt and dockerfile...")
     
     if(dockerFile == "False"):
-        try: 
+        try:
+            printInfo("Building dockerfile...")
             buildDocker(project_directory)
             printInfo("Dockerfile created successfully.")
         except Exception as e:
@@ -172,7 +169,9 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
     if(requirementsFile == "False"):
         try: 
+            printInfo("Building requirements.txt...")
             os.system(f'pipreqs --force {project_directory}')
+            printInfo("requirements.txt created successfully")
         except Exception as e:
             logging.error(e, exc_info=True)
             printError(f"ERROR. Deployment failed. Failed to create requirements.txt with error: {e}")
@@ -347,15 +346,15 @@ def deployModel(model_name, version_name, project_directory, number_pods, requir
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("--model_name", help="The name you want to give your model", required=True)
-    parser.add_argument("--version_name", help="The name you want to give this version of your model", required=True)
-    parser.add_argument("--project_directory", help="The directory of your project. Put only what you need to run predictions using your model in it.", required=True)
-    parser.add_argument("--number_pods", help="The number of pods of your deployment if you are providing your own", required=False, default=1)
-    parser.add_argument("--keep_alive", help="How many hours the model should remain active without any usage. Anything greater than 8 hours may incur additional cost. You will experience a cold start once this time period expires. Defaults to 8", required=False, default=8, type=int)
+    parser.add_argument("--model-name", help="The name you want to give your model", required=True)
+    parser.add_argument("--version-name", help="The name you want to give this version of your model", required=True)
+    parser.add_argument("--project-directory", help="The directory of your project. Put only what you need to run predictions using your model in it.", required=True)
+    parser.add_argument("--number-pods", help="The number of pods of your deployment if you are providing your own", required=False, default=1)
+    parser.add_argument("--keep-alive", help="How many hours the model should remain active without any usage. Anything greater than 8 hours may incur additional cost. You will experience a cold start once this time period expires. Defaults to 8", required=False, default=8, type=int)
     parser.add_argument("--requirements", help="Did you create your own requirements.txt in your project directory or should we make you one? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
-    parser.add_argument("--memory_limit", help="The memory limit for your deployment in Gi if you are providing your own, else we will attempt to guess. Provide only the number with decimals.", required=False, default=-999.9, type=float)
+    parser.add_argument("--memory-limit", help="The memory limit for your deployment in Gi if you are providing your own, else we will attempt to guess. Provide only the number with decimals.", required=False, default=-999.9, type=float)
     parser.add_argument("--dockerfile", help="Did you create your own Dockerfile in your project directory or should we make you one? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
-    parser.add_argument("--verbose_logging", help="Do you want a bunch of logs? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
+    parser.add_argument("--verbose-logging", help="Do you want a bunch of logs? Answer True or False. Default False.", required=False, default="False", choices=["True","False"])
     
     args = parser.parse_args()
     deployModel(args.model_name, args.version_name, args.project_directory, args.number_pods, args.requirements, args.dockerfile, args.memory_limit, args.verbose_logging, args.keep_alive)
\ No newline at end of file
