@@ -35,7 +35,7 @@ def get_pod_ids(model_name):
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("--model_name", help="The name of your deployed model", required=True)
+    parser.add_argument("--model-name", help="The name of your deployed model", required=True)
     args = parser.parse_args()
 
     print(get_pod_ids(args.model_name))
\ No newline at end of file
